@@ -1,13 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import os
 import sys
 
 from . import get_html_templates_path
 
-PY3 = sys.version_info[0] >= 3
-
 LINKCODE_URL = 'https://github.com/{proj}/tree/{branch}/{filename}.py'
 GITHUB_BRANCH = 'master'
 
@@ -32,15 +27,19 @@ EXTENSIONS = [
 INTERSPHINX_MAPPING = {
     'python': ('https://docs.python.org/dev/', None),
     'sphinx': ('https://www.sphinx-doc.org/en/stable/', None),
-    'kombu': ('https://kombu.readthedocs.io/en/master/', None),
-    'celery': ('https://docs.celeryproject.org/en/master', None),
+    'kombu': ('https://kombu.readthedocs.io/en/main/', None),
+    'celery': ('https://celery.readthedocs.io/en/main/', None),
+    'pytest-celery': ('https://pytest-celery.readthedocs.io/en/main/', None),
     'djcelery': ('https://django-celery.readthedocs.io/en/latest/', None),
     'cyme': ('https://cyme.readthedocs.io/en/latest/', None),
     'amqp': ('https://amqp.readthedocs.io/en/latest/', None),
     'vine': ('https://vine.readthedocs.io/en/latest/', None),
     'flower': ('https://flower.readthedocs.io/en/latest/', None),
     'redis': ('https://redis-py.readthedocs.io/en/latest/', None),
-    'django': ('https://django.readthedocs.io/en/latest/', None),
+    'django': (
+        'http://docs.djangoproject.com/en/dev/',
+        'https://docs.djangoproject.com/en/dev/_objects',
+    ),
     'boto': ('https://boto.readthedocs.io/en/latest/', None),
     'sqlalchemy': ('https://sqlalchemy.readthedocs.io/en/latest', None),
     'kazoo': ('https://kazoo.readthedocs.io/en/latest/', None),
@@ -50,12 +49,10 @@ INTERSPHINX_MAPPING = {
     'eventlet': ('https://eventlet.net/doc/', None),
     'gevent': ('http://www.gevent.org/', None),
     'pyOpenSSL': ('https://pyopenssl.readthedocs.io/en/stable/', None),
-    'pytest': ('https://doc.pytest.org/en/latest/', None),
+    'pytest': ('https://docs.pytest.org/en/latest/', None),
     'tox': ('https://tox.readthedocs.io/en/latest', None),
 }
 
-string_types = (str,) if PY3 else (basestring,)
-
 
 def add_paths(config_file, path_additions):
     this = os.path.dirname(os.path.abspath(config_file))
@@ -69,7 +66,7 @@ def configure_django(django_settings, **config):
     if django_settings:
         os.environ['DJANGO_SETTINGS_MODULE'] = django_settings
     else:
-        from django.conf import settings  # noqa
+        from django.conf import settings
         if not settings.configured:
             settings.configure(**config)
     try:
@@ -81,7 +78,7 @@ def configure_django(django_settings, **config):
 
 
 def import_package(package):
-    if isinstance(package, string_types):
+    if isinstance(package, str):
         return __import__(package)
     return package
 
@@ -89,9 +86,9 @@ def import_package(package):
 def prepare_intersphinx_mapping(project, mapping,
                                 include, exclude, **extra):
     if include:
-        mapping = dict((k, v) for k, v in mapping.items() if k in include)
+        mapping = {k: v for k, v in mapping.items() if k in include}
     if exclude:
-        mapping = dict((k, v) for k, v in mapping.items() if k not in exclude)
+        mapping = {k: v for k, v in mapping.items() if k not in exclude}
     mapping = dict(mapping, **extra)
 
     # Remove project itself from intersphinx
@@ -157,26 +154,26 @@ def build_config(
     extlinks = extlinks or {}
 
     extlinks.setdefault('sha', (
-        'https://github.com/{0}/commit/%s'.format(github_project),
-        'GitHub SHA@',
+        f'https://github.com/{github_project}/commit/%s',
+        'GitHub SHA@%s',
     ))
     extlinks.setdefault('github_branch', (
-        'https://github.com/{0}/tree/%s'.format(github_project),
-        'GitHub branch',
+        f'https://github.com/{github_project}/tree/%s',
+        'GitHub branch %s',
     ))
     extlinks.setdefault('github_user', (
-        'https://github.com/%s/', '@',
+        'https://github.com/%s/', '@%s',
     ))
     extlinks.setdefault('pypi', (
-        'https://pypi.python.org/pypi/%s/', '',
+        'https://pypi.org/project/%s/', None,
     ))
     extlinks.setdefault('wikipedia', (
-        'https://en.wikipedia.org/wiki/%s', '',
+        'https://en.wikipedia.org/wiki/%s', None,
     ))
 
     if not canonical_dev_url:
         canonical_dev_url = '/'.join([
-            canonical_url.rstrip('/'), 'en', 'master',
+            canonical_url.rstrip('/'), 'en', 'main',
         ])
     if not canonical_stable_url:
         canonical_stable_url = '/'.join([
@@ -212,7 +209,7 @@ def build_config(
         # The master toctree document.
         master_doc=master_doc,
 
-        copyright='{0}, {1}'.format(copyright, author),
+        copyright=f'{copyright}, {author}',
 
         # The short X.Y version.
         version=version,
@@ -270,22 +267,22 @@ def build_config(
 
         man_pages=[
             (master_doc, project.lower(),
-             u'{0} Documentation'.format(project), [author_name], 1)
+             f'{project} Documentation', [author_name], 1)
         ],
 
         # Grouping the document tree into Texinfo files. List of tuples
         # (source start file, target name, title, author,
         #  dir menu entry, description, category)
         texinfo_documents=[
-            (master_doc, project, u'{0} Documentation'.format(project),
+            (master_doc, project, f'{project} Documentation',
              author_name, project, description,
              'Miscellaneous'),
         ],
         latex_logo=latex_logo or html_logo,
 
         latex_documents=[
-            ('index', '{0}.tex'.format(project),
-             '{0} Documentation'.format(project), author, 'manual'),
+            ('index', f'{project}.tex',
+             f'{project} Documentation', author, 'manual'),
         ],
         html_theme='sphinx_celery',
         html_sidebars={
@@ -300,7 +297,7 @@ def build_config(
             ],
         },
         # Bibliographic Dublin Core info.
-        epub_title='{0} Manual, Version {1}'.format(project, version),
+        epub_title=f'{project} Manual, Version {version}',
         epub_author=author_name,
         epub_publisher=publisher or author_name,
         epub_copyright=copyright,
@@ -317,7 +314,7 @@ def build_config(
         epub_identifier=webdomain,
 
         # A unique identification for the text.
-        epub_uid='{0} Manual, Version {0}'.format(project, version),
+        epub_uid=f"{project} Manual, Version {version}",
 
         # A list of files that should not be packed into the epub file.
         epub_exclude_files=['search.html'],
